@@ -130,7 +130,7 @@ def company_profile(apikey: str, symbol: str) -> typing.List[typing.Dict]:
     Gather this company's information.
     :param apikey: Your API key.
     :param symbol: Ticker of Company.
-   """
+    """
     path = f"profile/{symbol}"
     query_vars = {"apikey": apikey}
     return __return_json(path=path, query_vars=query_vars)
@@ -325,7 +325,9 @@ def financial_statement_symbol_lists(apikey: str) -> typing.List[typing.Dict]:
 
 
 def income_statement_growth(
-    apikey: str, symbol: str, limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /income-statement-growth/ API.
@@ -490,7 +492,9 @@ def cash_flow_statement_as_reported(
 
 
 def financial_statement_full_as_reported(
-    apikey: str, symbol: str, period: str = "annual",
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /financial-statement-full-as-reported/ API.
@@ -520,7 +524,10 @@ def financial_ratios_ttm(apikey: str, symbol: str) -> typing.List[typing.Dict]:
 
 
 def financial_ratios(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FmP /ratios/ API.
@@ -541,7 +548,10 @@ def financial_ratios(
 
 
 def enterprise_values(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /enterprise-values/ API.
@@ -562,7 +572,9 @@ def enterprise_values(
 
 
 def key_metrics_ttm(
-    apikey: str, symbol: str, limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /key-metrics-ttm/ API
@@ -578,7 +590,10 @@ def key_metrics_ttm(
 
 
 def key_metrics(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /key-metrics/ API
@@ -599,7 +614,10 @@ def key_metrics(
 
 
 def financial_growth(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /financial-growth/ API.
@@ -633,7 +651,9 @@ def rating(apikey: str, symbol: str) -> typing.List[typing.Dict]:
 
 
 def historical_rating(
-    apikey: str, symbol: str, limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /financial-growth/ API.
@@ -662,7 +682,10 @@ def discounted_cash_flow(apikey: str, symbol: str) -> typing.List[typing.Dict]:
 
 
 def historical_discounted_cash_flow(
-    apikey: str, symbol: str, period: str = "annual", limit: int = DEFAULT_LIMIT,
+    apikey: str,
+    symbol: str,
+    period: str = "annual",
+    limit: int = DEFAULT_LIMIT,
 ) -> typing.List[typing.Dict]:
     """
     Query FMP /historical-discounted-cash-flow/ API.
@@ -749,6 +772,10 @@ def stock_screener(
     volume_lower_than: typing.Union[float, int] = None,
     dividend_more_than: typing.Union[float, int] = None,
     dividend_lower_than: typing.Union[float, int] = None,
+    price_more_than: typing.Union[float, int] = None,
+    price_lower_than: typing.Union[float, int] = None,
+    is_ETF: bool = None,
+    is_actively_trading: bool = None,
     sector: str = None,
     industry: str = None,
     exchange: typing.Union[str, typing.List[str]] = None,
@@ -766,6 +793,10 @@ def stock_screener(
     :param volume_lower_than:  Numeric Value
     :param dividend_more_than:  Numeric Value
     :param dividend_lower_than:  Numeric Value
+    :price_more_than: Numeric Value
+    :price_lower_than: Numeric Value
+    :is_ETF: bool
+    :is_actively_trading: bool
     :param sector: Valid sector name.
     :param industry: Valid industry name.
     :param exchange: Stock exchange symbol.
@@ -790,6 +821,14 @@ def stock_screener(
         query_vars["dividendMoreThan"] = dividend_more_than
     if dividend_lower_than:
         query_vars["dividendLowerThan"] = dividend_lower_than
+    if price_more_than:
+        query_vars["priceMoreThan"] = price_more_than
+    if price_lower_than:
+        query_vars["priceLowerThan"] = price_lower_than
+    if is_ETF:
+        query_vars["isEtf"] = is_ETF
+    if is_actively_trading:
+        query_vars["isActivelyTrading"] = is_actively_trading
     if sector:
         query_vars["sector"] = __validate_sector(sector)
     if industry:
@@ -1285,7 +1324,9 @@ def indexes(apikey: str) -> typing.List[typing.Dict]:
 
 
 def sp500_constituent(
-    apikey: str, download: bool = False, filename: str = SP500_CONSTITUENTS_FILENAME,
+    apikey: str,
+    download: bool = False,
+    filename: str = SP500_CONSTITUENTS_FILENAME,
 ) -> typing.Union[typing.List[typing.Dict], None]:
     """
     Query FMP /sp500_constituent/ API
@@ -1319,7 +1360,9 @@ def historical_sp500_constituent(apikey: str) -> typing.List[typing.Dict]:
 
 
 def nasdaq_constituent(
-    apikey: str, download: bool = False, filename: str = NASDAQ_CONSTITUENTS_FILENAME,
+    apikey: str,
+    download: bool = False,
+    filename: str = NASDAQ_CONSTITUENTS_FILENAME,
 ) -> typing.Union[typing.List[typing.Dict], None]:
     """
     Query FMP /nasdaq_constituent/ API
@@ -1353,7 +1396,9 @@ def historical_nasdaq_constituent(apikey: str) -> typing.List[typing.Dict]:
 
 
 def dowjones_constituent(
-    apikey: str, download: bool = False, filename: str = DOWJONES_CONSTITUENTS_FILENAME,
+    apikey: str,
+    download: bool = False,
+    filename: str = DOWJONES_CONSTITUENTS_FILENAME,
 ) -> typing.Union[typing.List[typing.Dict], None]:
     """
     Query FMP /dowjones_constituent/ API
@@ -1590,7 +1635,7 @@ def available_cryptocurrencies(apikey: str) -> typing.List[typing.Dict]:
     :param apikey: Your API key.
     :return: A list of dictionaries.
     """
-    path = f"symbol/available-tsx"
+    path = f"symbol/available-cryptocurrencies"
     query_vars = {"apikey": apikey}
     return __return_json(path=path, query_vars=query_vars)
 
